@@ -1,5 +1,5 @@
 from paypalrestsdk.api import Api, set_config, configure
-from paypalrestsdk.payments import Payment, Sale, Refund, Authorization, Capture, BillingPlan, BillingAgreement
+from paypalrestsdk.payments import Payment, Sale, Refund, Authorization, Capture, BillingPlan, BillingAgreement, Order
 from paypalrestsdk.invoices import Invoice
 from paypalrestsdk.vault import CreditCard
 from paypalrestsdk.openid_connect import Tokeninfo, Userinfo
